---

title: Stats

keywords: fastai
sidebar: home_sidebar

summary: "Algoritmos de detecção de Anomalias"
description: "Algoritmos de detecção de Anomalias"
---
<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: 00_core.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

<div class="container" id="notebook-container">
        
    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

</div>
    {% endraw %}

<div class="cell border-box-sizing text_cell rendered"><div class="inner_cell">
<div class="text_cell_render border-box-sizing rendered_html">
<h2 id="Robust-Zscore">Robust Zscore<a class="anchor-link" href="#Robust-Zscore"> </a></h2><p>Para detecção de anomalias o Zscore Robusto é mais adequado que o Zscore padrão, uma vez que a média pode ser fortemente influenciada por outliers.</p>

</div>
</div>
</div>
    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

</div>
    {% endraw %}

    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

<div class="output_wrapper">
<div class="output">

<div class="output_area">


<div class="output_markdown rendered_html output_subarea ">
<h2 id="MAD" class="doc_header"><code>class</code> <code>MAD</code><a href="https://github.com/fillipedem/pyanomaly/tree/master/pyanomaly/stats.py#L8" class="source_link" style="float:right">[source]</a></h2><blockquote><p><code>MAD</code>()</p>
</blockquote>
<p>classe responsavel por implemetar zscore robusto
para detecção de anomalias.</p>

</div>

</div>

</div>
</div>

</div>
    {% endraw %}

</div>
 

