---

title: utils

keywords: fastai
sidebar: home_sidebar

summary: "#TODO"
description: "#TODO"
---
<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: 03_utils.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

<div class="container" id="notebook-container">
        
    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

</div>
    {% endraw %}

    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

</div>
    {% endraw %}

    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

</div>
    {% endraw %}

    {% raw %}
    
<div class="cell border-box-sizing code_cell rendered">

<div class="output_wrapper">
<div class="output">

<div class="output_area">


<div class="output_markdown rendered_html output_subarea ">
<h4 id="plot_anomalies" class="doc_header"><code>plot_anomalies</code><a href="https://github.com/fillipedem/pyanomaly/tree/master/pyanomaly/utils.py#L10" class="source_link" style="float:right">[source]</a></h4><blockquote><p><code>plot_anomalies</code>(<strong><code>ts</code></strong>, <strong><code>anomalies</code></strong>, <strong><code>figsize</code></strong>=<em><code>(20, 5)</code></em>, <strong><code>s</code></strong>=<em><code>50</code></em>, <strong><code>anomaly_color</code></strong>=<em><code>'red'</code></em>)</p>
</blockquote>
<p>Input:
    ts: Series object  with DatetimeIndex
    anomalias: Series object with DatetimeIndex
Output:
    fig, ax</p>

</div>

</div>

</div>
</div>

</div>
    {% endraw %}

</div>
 

